#
# spec file for package kfilemetadata5
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without ffmpeg
%bcond_without lang
%define _tar_path 5.45
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %global _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
Name:           kfilemetadata5
Version:        5.45.0
Release:        lp150.1.1
%define kf5_version %{version}
Summary:        Extract Metadata
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND LGPL-3.0-only
Group:          Development/Libraries/KDE
Url:            http://www.kde.org/
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/kfilemetadata-%{version}.tar.xz
Source1:        baselibs.conf
Patch0:         ffmpeg-buildrequires.patch
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
%endif
BuildRequires:  karchive-devel >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel >= %{_kf5_bugfix_version}
BuildRequires:  libattr-devel
BuildRequires:  libepub-devel
BuildRequires:  libexiv2-devel >= 0.21
BuildRequires:  taglib-devel >= 1.9
BuildRequires:  cmake(Qt5Multimedia) >= 5.6.0
BuildRequires:  cmake(Qt5Test) >= 5.6.0
BuildRequires:  cmake(Qt5Xml) >= 5.6.0
BuildRequires:  pkgconfig(poppler-qt5)
Recommends:     catdoc
%if %{with lang}
Recommends:     %{name}-lang
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A library for extracting file metadata.

%package devel
Summary:        Development package for kfilemetadata
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules >= %{_kf5_bugfix_version}
Requires:       cmake(Qt5Core) >= 5.6.0

%description devel
A library for extracting file metadata. Development files

%lang_package
%prep
%setup -q -n kfilemetadata-%{version}
%patch0 -p1

%build
  %cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
  %make_jobs

%install
  %kf5_makeinstall -C build
%if %{with lang}
  %kf5_find_lang
%endif

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING*
%{_kf5_plugindir}/
%{_kf5_libdir}/libKF5FileMetaData.so.*
%{_kf5_debugdir}/*.categories

%files devel
%defattr(-,root,root)
%doc COPYING*
%{_kf5_libdir}/libKF5FileMetaData.so
%{_kf5_includedir}/KFileMetaData/
%{_kf5_libdir}/cmake/KF5FileMetaData/

%if %{with lang}
%files lang -f %{name}.lang
%doc COPYING*
%endif

%changelog
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * taglibextractor: Refactor for better readability
* Tue Mar 13 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Tue Feb 13 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Fix build with >=attr-2.4.48
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Use more explicit
  * Use more nullptr
  * Use nullptr, const'ify, port some Q_FOREACH to for(..:..)
  * Fix build against TagLib < 1.11
  * remove extractor based on QtMultimedia
  * Check for Linux instead of TagLib and avoid building the usermetadatawritertest on Windows.
  * Restore # 6c9111a9 until a successful build and link without TagLib is possible.
  * Remove the taglib dependency, caused by a left-over include. Also reverts commit # 6c9111a9
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * The usermetadatawritertest requires Taglib. Therefore if Taglib isn't around, we shouldn't try to build something that requires it. This fixes the build on Windows.
  * Port to debug category
  * Fix UserMetaData unit tests.
  * User meta data (xattr key-value) unit tests.
  * Simplify empty rating check.
  * If the property value is null, remove the user.xdg.tag attribute. (kde#376117)
  * Open files in TagLib extractor readonly
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Fix display name of Generator property
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * fix crash when more than one instances of ExtractorCollection are destructed
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * in automatic tests, find python interpreter and use it for python test scripts
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Fix Python dependency in test scripts for KFileMetaData (bug 375472)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Fix configure with Qt5Multimedia disabled.
  * add an extractor using qtmultimedia
  * [FEATURE] Option to build & install QCH file with the public API dox
  * fix warnings from clazy with the default warning level
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * use /usr/bin/env to locate python2
  * Use right QProcess API
  * fix build against Android NDK (API Level 21 is required)
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Rename the translation template (avoid conflicts)
  * makes KArchive be optional and do not build extractors needing it
  * cmake: switch to the FindPoppler module from ECM
  * fix duplicated symbols compilation error with mingw on Windows
  * autotests: Use QTEST_GUILESS_MAIN
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Make PlainTextExtractor match "text/plain" again
  * Upgrade KF5 version to 5.33.0.
- Remove patches, now upstream:
  * Make-PlainTextExtractor-match-text-plain-again.patch
* Mon Mar 20 2017 wbauer@tmo.at
- Add Make-PlainTextExtractor-match-text-plain-again.patch to fix
  metadata extraction for text files which got broken in 5.32.0
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
  * fix build of kfilemetadata with taglib version 1.9
  * New maintainer for kfilemetadata
  * [ExtractorCollection] Use mimetype inheritance to return plugins
  * add a new property DiscNumber for audio files from multi-disc albums
  * add more audio format to automatic test and fix problems
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Mon Jan  9 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Actually find FFMpeg's libpostproc
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sun Nov  6 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Improve epub extractor, less segfaults (kde#361727)
  * Make odf indexer more error prove, check if the files are there
    (and are files at all) (meta.xml + content.xml)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Only require Xattr if the operating system is Linux
  * Restore Windows build
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Check for xattr during config step, otherwise the build
    might fail (if xattr.h is missing)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Fixed external plugins and tests
  * Added support for external writer plugins
  * Added writer plugin support
  * Add external extractor plugin support
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Sun Apr 17 2016 olaf@aepfle.de
- Use pkgconfig instead of libffmpeg-devel
  ffmpeg-buildrequires.patch
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * KFileMetadata can now query and store information about the
    original email a saved file may have been an attachment of
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Allow querying for a file's origin URL
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Mon Jan 11 2016 wbauer@tmo.at
- Build against poppler-qt5 on SLE12 and Leap 42 as well, it is
  available meanwhile (boo#953957)
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Fri Dec 11 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Mark m4a as readable by taglib
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Implement windows usermetadata
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * PlainTextExtractor: enable O_NOATIME branch on GNU libc platforms
  * PlainTextExtractor: make the Linux branch work also without O_NOATIME
  * PlainTextExtractor: fix error check on open(O_NOATIME) failure
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Fri Sep  4 2015 hrvoje.senjan@gmail.com
- Only Recommend catdoc, to help reducing liveCD/DVD size
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix Oboletes/Provides versions regarding Leap versioning
* Mon Jul 20 2015 mlin@suse.com
- No poppler-qt5 in Leap 42, do not build with it on 42 and SLE
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Update required taglib version to 1.9
- Added libattr-devel BuildRequires
* Tue Mar 31 2015 hrvoje.senjan@gmail.com
- Enable ffmpeg support on openSUSE > 13.2
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Add lang subpackage
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Unconditionally BuildRequire pkgconfig(poppler-qt5)
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor API adjustements since previous snapshot
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140911 (r5d1c60d):
  * Use QPluginLoader instead of KService for loading the plugins.
  * API cleanups
- Drop kservice-devel BuildRequires, per upstream changes
- Add baselibs.conf
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Tue Jun  3 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0
  * Beta 2 of Plasma 5 release
- Add Source URL
* Sun May 18 2014 hrvoje.senjan@gmail.com
- Activate kfilemetadata5 package
